#***************************************************************#
#********************* Results case study **********************#
#***************************************************************#


##### 0) load packages, data and functions #####

### packages
library(dplyr)
library(survival)
library(tidyr)
library(ggplot2)
library(cowplot)
library(kableExtra)

# set path to folder including data and code
folderpath<-getwd() # adjust accordingly

# load data
data_replicate<-readRDS(file.path(folderpath,"Info_replicates.rds"))

# estimation results
load(file.path(folderpath,"Results_case_study.RData"))

# colors
alpha<-0.3
colors<-c("black","#0072B2",'orange',"darkgray")#"#999999")
tcolor<-c(rgb(col2rgb("#999999")[1],col2rgb("#999999")[2],col2rgb("#999999")[3],
              maxColorValue=255,alpha=alpha*255),
          rgb(col2rgb("#0072B2")[1],col2rgb("#0072B2")[2],col2rgb("#0072B2")[3],
              maxColorValue=255,alpha=alpha*255),
          rgb(col2rgb('orange')[1],col2rgb('orange')[2],col2rgb('orange')[3],
              maxColorValue=255,alpha=alpha*255))


##### 1) data frame with estimation results #####

# long format for plotting

# IDs
df_results <-data_replicate[,c("replicate","id_vole1","number_steps")]
df_results <- df_results[rep(seq_len(nrow(df_results)), each = 3*5), ]
rownames(df_results)<-NULL
df_results$id_other <- rep(as.vector(t(as.matrix(data_replicate[,3:5]))),each=5)
df_results$model<-c("iSSA","HMMiSSA.1","HMMiSSA.2","TSiSSA.1","TSiSSA.2")
# delete rows with NAs
df_results<-df_results[!is.na(df_results$id_other),]

# add selection coefficient estimates
df_results$beta<-NA
df_results$CI_low<-NA
df_results$CI_up<-NA
# iSSA
df_results$beta[df_results$model=="iSSA"]<-mapply(function(mod,n) return(mod$coefficients[1:n,1]),
                 mod=iSSA,n=data_replicate$number_voles-1) %>% unlist() %>% as.numeric()
df_results$CI_low[df_results$model=="iSSA"]<-mapply(function(mod,n) return(log(mod$conf.int[1:n,3])),
                                                    mod=iSSA,n=data_replicate$number_voles-1) %>% unlist() %>% as.numeric()
df_results$CI_up[df_results$model=="iSSA"]<-mapply(function(mod,n) return(log(mod$conf.int[1:n,4])),
                                                    mod=iSSA,n=data_replicate$number_voles-1) %>% unlist() %>% as.numeric()

# HMM-iSSA
# # check stability of the minimum negative log-likelihood values found
# lapply(HMMiSSA_all,function(mod_list){
#   nllks<-sapply(mod_list,function(mod) return(mod$nllk)) # negative log-likelihood values
#   plot_lims<-c(min(nllks,na.rm=TRUE),max(nllks,na.rm=TRUE))+c(-1,1)
#   plot(nllks,xlab='run',ylab='neg. ll',main='',ylim=plot_lims)
# })
# HMM-iSSAs with minimum negative log-likelihood value
HMMiSSA_mle<-lapply(HMMiSSA_all,function(mod_list){
  nllks<-sapply(mod_list,function(mod) return(mod$nllk)) # negative log-likelihood values
  return(mod_list[[which.min(nllks)]])
})
# # check state order:
# apply(sapply(HMMiSSA_mle,function(mod) return(mod$shape/mod$rate)),2,order)
# state 1
df_results$beta[df_results$model=="HMMiSSA.1"]<-lapply(HMMiSSA_mle,function(mod) return(mod$beta[,1])) %>% 
                                                      unlist() %>% as.numeric()
df_results$CI_low[df_results$model=="HMMiSSA.1"]<-lapply(HMMiSSA_mle,function(mod) return(mod$CI_low_beta[,1])) %>% 
                                                      unlist() %>% as.numeric()
df_results$CI_up[df_results$model=="HMMiSSA.1"]<-lapply(HMMiSSA_mle,function(mod) return(mod$CI_up_beta[,1])) %>% 
                                                      unlist() %>% as.numeric()
# state 2
df_results$beta[df_results$model=="HMMiSSA.2"]<-lapply(HMMiSSA_mle,function(mod) return(mod$beta[,2])) %>% 
  unlist() %>% as.numeric()
df_results$CI_low[df_results$model=="HMMiSSA.2"]<-lapply(HMMiSSA_mle,function(mod) return(mod$CI_low_beta[,2])) %>% 
  unlist() %>% as.numeric()
df_results$CI_up[df_results$model=="HMMiSSA.2"]<-lapply(HMMiSSA_mle,function(mod) return(mod$CI_up_beta[,2])) %>% 
  unlist() %>% as.numeric()

# TS-iSSA
# state 1
df_results$beta[df_results$model=="TSiSSA.1"]<-mapply(function(mod,n) return(mod$coefficients[1:n,1]),
                                                      mod=TSiSSA1,n=data_replicate$number_voles-1) %>% unlist() %>% as.numeric()
df_results$CI_low[df_results$model=="TSiSSA.1"]<-mapply(function(mod,n) return(log(mod$conf.int[1:n,3])),
                                                    mod=TSiSSA1,n=data_replicate$number_voles-1) %>% unlist() %>% as.numeric()
df_results$CI_up[df_results$model=="TSiSSA.1"]<-mapply(function(mod,n) return(log(mod$conf.int[1:n,4])),
                                                   mod=TSiSSA1,n=data_replicate$number_voles-1) %>% unlist() %>% as.numeric()
# state 2
df_results$beta[df_results$model=="TSiSSA.2"]<-mapply(function(mod,n) return(mod$coefficients[1:n,1]),
                                                          mod=TSiSSA2,n=data_replicate$number_voles-1) %>% unlist() %>% as.numeric()
df_results$CI_low[df_results$model=="TSiSSA.2"]<-mapply(function(mod,n) return(log(mod$conf.int[1:n,3])),
                                                        mod=TSiSSA2,n=data_replicate$number_voles-1) %>% unlist() %>% as.numeric()
df_results$CI_up[df_results$model=="TSiSSA.2"]<-mapply(function(mod,n) return(log(mod$conf.int[1:n,4])),
                                                       mod=TSiSSA2,n=data_replicate$number_voles-1) %>% unlist() %>% as.numeric()


##### 2) plots #####

##### 2a) add columns for plotting #####

# replicate order
df_results$replicate<-factor(df_results$replicate,
                             levels=paste("Rep",1:8,sep=""))
# replicate label (including number of steps)
df_results$repli_label<-paste(df_results$replicate,"\n(",
                              df_results$number_steps,
                              " steps)",sep="") %>% factor()

# label for males/females
df_results <-df_results %>% mutate(vole_label=case_when(id_vole1=="m1" ~ "male 1",
                                                       id_vole1=="m2" ~ "male 2",
                                                       id_vole1=="f1" ~ "female 1",
                                                       id_vole1=="f2" ~ "female 2",
                                                       TRUE ~ NA))
df_results$vole_label<-factor(df_results$vole_label,
                              levels=c("male 1","male 2","female 1","female 2"))

# color label
df_results$color_label<-rep(c("iSSA","HMM-iSSA\n state 1","HMM-iSSA\n state 2",
                              "TS-iSSA\n state 1","TS-iSSA\n state 2"),72) # index for state
df_results$color_label<-ifelse(df_results$CI_low < 0 & df_results$CI_up > 0,
                               "non sig.",df_results$color_label) %>% 
  factor(levels=c("iSSA","HMM-iSSA\n state 1","HMM-iSSA\n state 2",
                  "TS-iSSA\n state 1","TS-iSSA\n state 2","non sig."))

# x-axis
df_results$x <- rep(c(1,2,3,2,3),72) # similar to state index
df_results$x<-df_results$x+ifelse(df_results$id_other=="f1" | df_results$id_other=="m1",
                                              -0.12,+0.12)

##### 2b) plots iSSA/HMM-iSSA opposite sex #####

p_hmmissa_males_opp <- df_results %>% filter(id_vole1 %in% c("m1","m2")) %>%
  filter(id_other %in% c("f1","f2") & model %in% c("iSSA","HMMiSSA.1","HMMiSSA.2")) %>% ggplot() + 
  geom_hline(yintercept = 0, colour = gray(0.6), lty = "dashed") +
  geom_pointrange(aes(x=x, y=beta, ymin=CI_low, ymax=CI_up,  
                      colour=color_label,
                      shape=as.factor(id_other)), 
                  size=0.4,position=position_dodge2(width=0.5)) +
  scale_colour_manual(values = colors,name="") +
  facet_grid(repli_label ~ vole_label, scales = "free") +
  scale_y_continuous(breaks=c(-4, 0, 4)) +
  coord_cartesian(ylim = c(-6,4)) +
  scale_x_continuous(breaks=c(1, 2, 3), labels=c("iSSA",
                                                 "state 1\n                 HMM-iSSA",
                                                 "state 2")) +
  labs(y="", x="",tag = "a)") + 
  theme(legend.position="none") + 
  theme(axis.title = element_text(size=12), axis.text = element_text(size=11), 
        strip.text = element_text(size=13)) + 
  theme(axis.title.x = element_text(margin=margin(t=10)), axis.title.y = element_text(margin=margin(r=10))) +
  theme(plot.margin = margin(t=0.1, r=0.1, b=0.1, l=0.1, unit = "in")) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, linewidth=0.5),
        panel.background = element_blank(),
        legend.position='bottom',
        axis.text.x = element_text(size = 9),
        legend.key = element_rect(fill = "white"))

p_hmmissa_females_opp <- df_results %>% filter(id_vole1 %in% c("f1","f2")) %>%
  filter(id_other %in% c("m1","m2") & model %in% c("iSSA","HMMiSSA.1","HMMiSSA.2")) %>% ggplot() + 
  geom_hline(yintercept = 0, colour = gray(0.6), lty = "dashed") +
  geom_pointrange(aes(x=x, y=beta, ymin=CI_low, ymax=CI_up,  
                      colour=color_label,
                      shape=as.factor(id_other)), 
                  size=0.4,position=position_dodge2(width=0.5)) +
  scale_colour_manual(values = colors,name="") +
  facet_grid(repli_label ~ vole_label, scales = "free") +
  scale_y_continuous(breaks=c(-4, 0, 4)) +
  coord_cartesian(ylim = c(-6,4)) +
  scale_x_continuous(breaks=c(1, 2, 3), labels=c("iSSA",
                                                 "state 1\n                 HMM-iSSA",
                                                 "state 2")) +
  labs(y="", x="",tag = "a)") + 
  theme(legend.position="none") + 
  theme(axis.title = element_text(size=12), axis.text = element_text(size=11), 
        strip.text = element_text(size=13)) + 
  theme(axis.title.x = element_text(margin=margin(t=10)), axis.title.y = element_text(margin=margin(r=10))) +
  theme(plot.margin = margin(t=0.1, r=0.1, b=0.1, l=0.1, unit = "in")) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, linewidth=0.5),
        panel.background = element_blank(),
        legend.position='bottom',
        axis.text.x = element_text(size = 9),
        legend.key = element_rect(fill = "white"))

# save plot
ggdraw() +
  draw_plot(p_hmmissa_males_opp + theme(legend.position="none"), x=0, y=0, width=0.5, height=1) +
  draw_plot(p_hmmissa_females_opp + theme(legend.position="none"), x=0.5, y=0, width=0.5, height=1)

ggsave(file.path(folderpath,"Voles_hmmissa_opp.pdf"),width=10, height=10)


##### 2c) plots iSSA/HMM-iSSA same sex #####

p_hmmissa_same <- df_results %>% filter((id_vole1=="m1" & id_other=="m2") |  
                                      (id_vole1=="m2" & id_other=="m1") |
                                      (id_vole1=="f1" & id_other=="f2") |  
                                      (id_vole1=="f2" & id_other=="f1")) %>% 
  filter(model %in% c("iSSA","HMMiSSA.1","HMMiSSA.2") ) %>% ggplot() + 
  geom_hline(yintercept = 0, colour = gray(0.6), lty = "dashed") +
  geom_pointrange(aes(x=x, y=beta, ymin=CI_low, ymax=CI_up,  
                      colour=color_label),
                  position=position_dodge2(width=0.5), size=0.4) +
  scale_colour_manual(values = colors,name="") +
  facet_grid(repli_label ~ vole_label, scales = "free") +
  scale_y_continuous(breaks=c(-4, 0, 4)) +
  coord_cartesian(ylim = c(-6,4)) +
  scale_x_continuous(breaks=c(1, 2, 3), labels=c("iSSA",
                                                 "state 1\n                 HMM-iSSA",
                                                 "state 2")) +
  labs(y="", x="") + 
  # theme_grey() +
  theme(legend.position="none") + 
  theme(axis.title = element_text(size=12), axis.text = element_text(size=11), 
        strip.text = element_text(size=13)) + 
  theme(axis.title.x = element_text(margin=margin(t=10)), axis.title.y = element_text(margin=margin(r=10))) +
  theme(plot.margin = margin(t=0.1, r=0.1, b=0.1, l=0.1, unit = "in")) +  # set t=0.3 or so for attraction/avoidance annotation --> add xlim=c(1,2) in coord_flip
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, linewidth=0.5),
        panel.background = element_blank(),
        legend.position='bottom',
        axis.text.x = element_text(size = 9),
        legend.key = element_rect(fill = "white"))

# save plot
p_hmmissa_same
ggsave(file.path(folderpath,"Voles_hmmissa_same.pdf"),width=8, height=10)


##### 2d) plot TS-iSSA opposite sex #####

p_tsissa_males_opp <- df_results %>% filter(id_vole1 %in% c("m1","m2")) %>%
  filter(id_other %in% c("f1","f2") & model %in% c("TSiSSA.1","TSiSSA.2")) %>% ggplot() + 
  geom_hline(yintercept = 0, colour = gray(0.6), lty = "dashed") +
  geom_pointrange(aes(x=x, y=beta, ymin=CI_low, ymax=CI_up,  
                      colour=color_label,
                      shape=as.factor(id_other)), 
                  size=0.4,position=position_dodge2(width=0.5)) +
  scale_colour_manual(values = colors[-1],name="") +
  facet_grid(repli_label ~ vole_label, scales = "free") +
  scale_y_continuous(breaks=c(-4, 0, 4)) +
  coord_cartesian(ylim = c(-6,4)) +
  scale_x_continuous(breaks=c(2, 3), labels=c("state 1\n                            TS-iSSA",
                                              "state 2")) +
  labs(y="", x="",tag = "a)") + 
  # theme_grey() +
  theme(legend.position="none") + 
  theme(axis.title = element_text(size=12), axis.text = element_text(size=11), 
        strip.text = element_text(size=13)) + 
  # theme(panel.background = element_rect(fill = "#f2f2f2", colour = "#e8e8e8"), strip.background=element_rect(fill="#dbe6e9")) + 
  theme(axis.title.x = element_text(margin=margin(t=10)), axis.title.y = element_text(margin=margin(r=10))) +
  theme(plot.margin = margin(t=0.1, r=0.1, b=0.1, l=0.1, unit = "in")) +  # set t=0.3 or so for attraction/avoidance annotation --> add xlim=c(1,2) in coord_flip
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, linewidth=0.5),
        panel.background = element_blank(),
        legend.position='bottom',
        axis.text.x = element_text(size = 9),
        legend.key = element_rect(fill = "white"))


p_tsissa_females_opp <- df_results %>% filter(id_vole1 %in% c("f1","f2")) %>%
  filter(id_other %in% c("m1","m2") & model %in% c("TSiSSA.1","TSiSSA.2")) %>% ggplot() + 
  geom_hline(yintercept = 0, colour = gray(0.6), lty = "dashed") +
  geom_pointrange(aes(x=x, y=beta, ymin=CI_low, ymax=CI_up,  
                      colour=color_label,
                      shape=as.factor(id_other)), 
                  size=0.4,position=position_dodge2(width=0.5)) +
  scale_colour_manual(values = colors[-1],name="") +
  facet_grid(repli_label ~ vole_label, scales = "free") +
  scale_y_continuous(breaks=c(-4, 0, 4)) +
  coord_cartesian(ylim = c(-6,4)) +
  scale_x_continuous(breaks=c(2, 3), labels=c("state 1\n                            TS-iSSA",
                                              "state 2")) +
  labs(y="", x="",tag = "a)") + 
  # theme_grey() +
  theme(legend.position="none") + 
  theme(axis.title = element_text(size=12), axis.text = element_text(size=11), 
        strip.text = element_text(size=13)) + 
  # theme(panel.background = element_rect(fill = "#f2f2f2", colour = "#e8e8e8"), strip.background=element_rect(fill="#dbe6e9")) + 
  theme(axis.title.x = element_text(margin=margin(t=10)), axis.title.y = element_text(margin=margin(r=10))) +
  theme(plot.margin = margin(t=0.1, r=0.1, b=0.1, l=0.1, unit = "in")) +  # set t=0.3 or so for attraction/avoidance annotation --> add xlim=c(1,2) in coord_flip
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, linewidth=0.5),
        panel.background = element_blank(),
        legend.position='bottom',
        axis.text.x = element_text(size = 9),
        legend.key = element_rect(fill = "white"))


# save plot
ggdraw() +
  draw_plot(p_tsissa_males_opp + theme(legend.position="none"), x=0, y=0, width=0.5, height=1) +
  draw_plot(p_tsissa_females_opp + theme(legend.position="none"), x=0.5, y=0, width=0.5, height=1) #+

ggsave(file.path(folderpath,"Voles_tsissa_opp.pdf"),width=10, height=10)


##### 2e) plots TS-iSSA same sex #####

p_tsissa_same <- df_results %>% filter((id_vole1=="m1" & id_other=="m2") |  
                                         (id_vole1=="m2" & id_other=="m1") |
                                         (id_vole1=="f1" & id_other=="f2") |  
                                         (id_vole1=="f2" & id_other=="f1")) %>% 
  filter(model %in% c("TSiSSA.1","TSiSSA.2") ) %>% ggplot() + 
  geom_hline(yintercept = 0, colour = gray(0.6), lty = "dashed") +
  geom_pointrange(aes(x=x, y=beta, ymin=CI_low, ymax=CI_up,  
                      colour=color_label),
                  position=position_dodge2(width=0.5), size=0.4) +
  scale_colour_manual(values = colors[-1],name="") +
  facet_grid(repli_label ~ vole_label, scales = "free") +
  scale_y_continuous(breaks=c(-4, 0, 4)) +
  coord_cartesian(ylim = c(-6,4)) +
  scale_x_continuous(breaks=c(1, 2, 3), labels=c("iSSA",
                                                 "state 1\n                 TS-iSSA",
                                                 "state 2")) +
  labs(y="", x="") + 
  # theme_grey() +
  theme(legend.position="none") + 
  theme(axis.title = element_text(size=12), axis.text = element_text(size=11), 
        strip.text = element_text(size=13)) + 
  theme(axis.title.x = element_text(margin=margin(t=10)), axis.title.y = element_text(margin=margin(r=10))) +
  theme(plot.margin = margin(t=0.1, r=0.1, b=0.1, l=0.1, unit = "in")) +  # set t=0.3 or so for attraction/avoidance annotation --> add xlim=c(1,2) in coord_flip
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, linewidth=0.5),
        panel.background = element_blank(),
        legend.position='bottom',
        axis.text.x = element_text(size = 9),
        legend.key = element_rect(fill = "white"))

# save plot
p_tsissa_same
ggsave(file.path(folderpath,"Voles_tsissa_same.pdf"),width=8, height=10)



##### 3) Viterbi #####

# change df_results to wider format
df_results<-df_results %>% dplyr::select(replicate,id_vole1,number_steps,id_other,
                                         model, beta, CI_up,CI_low) %>%
  pivot_wider(
    names_from = c(model,id_other), 
    values_from = c(beta,CI_up,CI_low)
  ) %>% as.data.frame()


##### 3a) HMM states and HMM-iSSA decoding #####

# load function
source(file.path(folderpath,"functions.R"))

# load data
vole_data<-readRDS(file.path(folderpath,"Vole_case_control.rds"))
ID_voles<-unique(vole_data$id_vole)

# add log step length and negative step length
vole_data$log_sl_hmmissa<-log(vole_data$sl_hmmissa)
vole_data$neg_sl_hmmissa<-(-vole_data$sl_hmmissa)
vole_data$log_sl_tsissa<-log(vole_data$sl_tsissa)
vole_data$neg_sl_tsissa<-(-vole_data$sl_tsissa)
Viterbi_HMMiSSA<-list()
df_results$freq_HMM_1<-NA
df_results$freq_HMM_2<-NA
df_results$freq_HMMiSSA_1<-NA
df_results$freq_HMMiSSA_2<-NA
# loop across all individuals
for(i_vole in 1:length(ID_voles)){
  print(paste("Individual",ID_voles[i_vole]))
  Viterbi_HMMiSSA[[i_vole]]<-list()
  # number of other individuals
  num_voles<-data_replicate$number_voles[i_vole]
  # covariates and formula
  names_covs<-c(paste("occ",2:num_voles,"_hmmissa",sep=""),
                "log_sl_hmmissa", "neg_sl_hmmissa", "strata(step_id)")
  formula_iSSA<-as.formula(paste("used ~", paste(names_covs,collapse="+")))
  # decoding
  Viterbi_HMMiSSA[[i_vole]]<-viterbi_hmmissa(mod_hmmissa= HMMiSSA_mle[[i_vole]],
                                           formula=formula_iSSA,
                                           data=vole_data[which(vole_data$id_vole==ID_voles[i_vole]),],
                                           ID="burst_id")
  df_results$freq_HMM_1[i_vole]<-vole_data %>% filter(id_vole==ID_voles[i_vole] & used==1 & HMM_state==1) %>% nrow()
  df_results$freq_HMM_2[i_vole]<-vole_data %>% filter(id_vole==ID_voles[i_vole] & used==1 & HMM_state==2) %>% nrow()
  df_results$freq_HMMiSSA_1[i_vole]<-sum(unlist(Viterbi_HMMiSSA[[i_vole]])==1)
  df_results$freq_HMMiSSA_2[i_vole]<-sum(unlist(Viterbi_HMMiSSA[[i_vole]])==2)
}
rm(vole_data)


##### 3b) table #####

tab_Vit<-df_results[,c("freq_HMM_1","freq_HMM_2","freq_HMMiSSA_1","freq_HMMiSSA_2")]/df_results$number_steps*100
tab_Vit<-round(tab_Vit,2) %>% rename(HMM_State_1=freq_HMM_1,HMM_State_2=freq_HMM_2,
                                     HMMiSSA_State_1=freq_HMMiSSA_1,HMMiSSA_State_2=freq_HMMiSSA_2) %>%
  mutate(Rep=df_results$replicate,Ind=df_results$id_vole1) %>% 
  relocate("Rep","Ind","HMM_State_1","HMM_State_2","HMMiSSA_State_1","HMMiSSA_State_2")
# order rows
tab_Vit$Ind<-factor(tab_Vit$Ind,levels=c("m1","m2","f1","f2"))
tab_Vit<-tab_Vit[order(tab_Vit$Rep,tab_Vit$Ind),]
kable(tab_Vit, booktabs = TRUE, caption = "Viterbi", 
      align = "c","latex" )%>%
  kable_styling(latex_options = "basic")



##### 4) gamma distribution #####

##### 4a) HMM-iSSA #####

# select range
z<-seq(0,30,0.01)
# data frame with gamma distribution values for all individuals
gamma_ggplot<-mapply(function(mod,i_vole,data,z,Vit){
  freq_states<-table(unlist(Viterbi_HMMiSSA[[i_vole]]))/data_replicate$number_steps[i_vole] %>% 
  as.numeric()
  state1=dgamma(z,shape=mod$shape[1],rate=mod$rate[1])*freq_states[1]
  state2=dgamma(z,shape=mod$shape[2],rate=mod$rate[2])*freq_states[2]
  replicate=data$replicate[i_vole]
  id_vole=data$id_vole1[i_vole]
  return(data.frame(z=z,state1=state1,state2=state2,
                    replicate=replicate,
                    id_vole=id_vole))
                },mod=HMMiSSA_mle,i_vole=1:28,MoreArgs=list(data=data_replicate,z=z,Vit=Viterbi_HMMiSSA),
  SIMPLIFY = FALSE)

gamma_ggplot<-do.call(rbind,gamma_ggplot)


gamma_ggplot <- gamma_ggplot %>% 
  mutate(id_vole=case_when(id_vole=="m1" ~ "male 1",
                           id_vole=="m2" ~ "male 2",
                           id_vole=="f1" ~ "female 1",
                           id_vole=="f2" ~ "female 2",
                           TRUE ~ NA),
         id_vole=factor(id_vole,
                        levels=c("male 1", "male 2", "female 1", "female 2")))


# change large gamma values such that y-axis does not exceed
gamma_ggplot$state1<-ifelse(gamma_ggplot$state1>0.2,NA,gamma_ggplot$state1)

# load vole data for histograms of observed step lengths
vole_data<-readRDS(file.path(folderpath,"Vole_case_control.rds")) %>%
  filter(used==1)
vole_data$replicate<-substr(vole_data$id_vole,1,4)
vole_data <- vole_data %>% 
  mutate(id_vole=substr(vole_data$id_vole,6,7), 
         id_vole=case_when(id_vole=="m1" ~ "male 1",
                           id_vole=="m2" ~ "male 2",
                           id_vole=="f1" ~ "female 1",
                           id_vole=="f2" ~ "female 2",
                           TRUE ~ NA),
         id_vole=factor(id_vole,
                        levels=c("male 1", "male 2", "female 1", "female 2")))

p_gamma_hmmissa<-vole_data %>% 
  ggplot()+
  geom_histogram(mapping=aes(x = sl_hmmissa,y =after_stat(density)),
                 binwidth = 2,boundary=0,color="black", fill="lightgray") +
  facet_grid(replicate~id_vole,scales = "free")+
  coord_cartesian(xlim = c(0,30)) +
  geom_line(data=gamma_ggplot,aes(x=z, y=state1, color="1"),linewidth=1.5) +
  geom_line(data=gamma_ggplot,aes(x=z, y=state2, color="2"),linewidth=1.5) +
  scale_colour_manual(values = colors[-c(1,4)],
                      name="",
                      labels=c("state 1", "state 2")) +
  scale_y_continuous(breaks=c(0,0.05,0.1,0.15 ,0.2)) +
  labs(y="denisty", x="step length") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, linewidth=0.5),
        panel.background = element_blank(),
        legend.position='bottom') +
  theme(axis.title = element_text(size=12), axis.text = element_text(size=10), 
        strip.text = element_text(size=13),
        legend.text = element_text(size=12) )


p_gamma_hmmissa
ggsave(file.path(folderpath,"Voles_gamma_hmmissa.pdf"),width=10, height=8)


##### 4b) TS-iSSA #####

# select range
z<-seq(0,30,0.01)
# data frame with gamma distribution values for all individuals
gamma_ggplot<-mapply(function(mod1,mod2,i_vole,data1,data2,z){
  freq_states<-data2[i_vole,c("freq_HMM_1","freq_HMM_2")] %>% 
    as.numeric()
  freq_states<-freq_states/data1$number_steps[i_vole]
  print(freq_states)
  gamma_pars<-tail(mod1$coefficients[,1],n=2)+
    c(data1$shape_HMM1[i_vole],data1$rate_HMM1[i_vole])
  state1=dgamma(z,shape=gamma_pars[1],rate=gamma_pars[2])*freq_states[1]
  gamma_pars<-tail(mod2$coefficients[,1],n=2)+
    c(data1$shape_HMM2[i_vole],data1$rate_HMM2[i_vole])
  state2=dgamma(z,shape=gamma_pars[1],rate=gamma_pars[2])*freq_states[2]
  replicate=data1$replicate[i_vole]
  id_vole=data1$id_vole1[i_vole]
  return(data.frame(z=z,state1=state1,state2=state2,
                    replicate=replicate,
                    id_vole=id_vole))
},mod1=TSiSSA1,mod2=TSiSSA2,i_vole=1:28,
MoreArgs=list(data1=data_replicate,data2=df_results,z=z),
SIMPLIFY = FALSE)

gamma_ggplot<-do.call(rbind,gamma_ggplot)

gamma_ggplot <- gamma_ggplot %>% 
  mutate(id_vole=case_when(id_vole=="m1" ~ "male 1",
                           id_vole=="m2" ~ "male 2",
                           id_vole=="f1" ~ "female 1",
                           id_vole=="f2" ~ "female 2",
                           TRUE ~ NA),
         id_vole=factor(id_vole,
                        levels=c("male 1", "male 2", "female 1", "female 2")))


# change large gamma values such that y-axis does not exceed
gamma_ggplot$state1<-ifelse(gamma_ggplot$state1>0.2,NA,gamma_ggplot$state1)


p_gamma_tsissa<-vole_data %>% 
  ggplot()+
  geom_histogram(mapping=aes(x = sl_hmmissa,y =after_stat(density)),
                 binwidth = 2,boundary=0,color="black", fill="lightgray") +
  facet_grid(replicate~id_vole,scales = "free")+
  coord_cartesian(xlim = c(0,30)) +
  geom_line(data=gamma_ggplot,aes(x=z, y=state1, color="1"),linewidth=1.5) +
  geom_line(data=gamma_ggplot,aes(x=z, y=state2, color="2"),linewidth=1.5) +
  scale_colour_manual(values = colors[-c(1,4)],
                      name="",
                      labels=c("state 1", "state 2")) +
  scale_y_continuous(breaks=c(0,0.05,0.1,0.15 ,0.2)) +
  labs(y="denisty", x="step length") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, linewidth=0.5),
        panel.background = element_blank(),
        legend.position='bottom') +
  theme(axis.title = element_text(size=12), axis.text = element_text(size=10), 
        strip.text = element_text(size=13),
        legend.text = element_text(size=12) )


p_gamma_tsissa
ggsave(file.path(folderpath,"Voles_gamma_tsissa.pdf"),width=10, height=8)
